==> js-api-creator-1.0.8.tgz: package/es/apiCreator.js <==
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _Object$keys from "babel-runtime/core-js/object/keys";
import _Object$assign from "babel-runtime/core-js/object/assign";
import requestAPI from './xhrApi';

var isFormData = function isFormData(payload) {

	if (typeof FormData !== "undefined" && payload) {
		return payload.constructor == new FormData().constructor;
	}

	return typeof payload == "function";
};

var Builder = function Builder(apiJson, options) {
	//Url and param builder..
	var apiOptions = function apiOptions() {
		var _method = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

		var requestUrl = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
		var parameters = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
		var queryParameters = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};


		var isFormDataFound = isFormData(parameters);

		var userParamsClone = _Object$assign({}, isFormDataFound ? queryParameters : parameters); // to address re-back call ajax parameters keeping..
		if (_Object$keys(userParamsClone).length) {
			var propsToUrl = requestUrl.split('/'); // helps to some parameter to url...
			for (var i = 0, len = propsToUrl.length; i < len; i++) {
				var prop = propsToUrl[i];
				var paramKey = prop.replace(':', '');
				if (prop.charAt(0) === ':' && userParamsClone.hasOwnProperty(paramKey)) {
					var value = userParamsClone[paramKey];
					requestUrl = requestUrl.replace('/' + prop, value ? '/' + value : '');
					requestUrl = requestUrl.replace(prop + '/', value ? value + '/' : '');
					delete userParamsClone[paramKey];
				}
			}
		}

		var userParams = isFormDataFound ? parameters : userParamsClone;
		queryParameters = isFormDataFound ? userParamsClone : queryParameters;

		var defaultParams = _Object$assign({}, queryParameters, options.defaultParams(_method));
		var gobalParamsToUrl = '';
		var count = 0;
		for (var prop in defaultParams) {
			if (count > 0) {
				gobalParamsToUrl += "&" + prop + "=" + defaultParams[prop];
				break;
			}
			gobalParamsToUrl += prop + "=" + defaultParams[prop];
			count = 1;
		}

		gobalParamsToUrl = gobalParamsToUrl ? '?' + gobalParamsToUrl : '';

		if (!isFormDataFound) {
			var length = userParams ? _Object$keys(userParams).length : 0;
			userParams = length > 0 ? userParams : null;
		}

		return {
			url: options.prefixUrl(_method) + requestUrl + gobalParamsToUrl,
			param: userParams
		};
	};

	//url - bind arguments not from user..
	var httpConnection = function httpConnection(ajaxmethod) {
		return function (url) {
			var ajaxoptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
			var ajaxoption2 = arguments[2];
			var ajaxoption3 = arguments[3];


			var urlHeaders = typeof options.authHeaders === "function" ? options.authHeaders(ajaxmethod) : null;
			if (typeof ajaxoptions === "function" || typeof ajaxoption2 === "function") {

				var _success = typeof ajaxoptions === "function" ? ajaxoptions : ajaxoption2;
				var _failure = typeof ajaxoptions === "function" ? ajaxoption2 : ajaxoption3;
				var _payload = typeof ajaxoptions === "function" ? null : ajaxoptions;

				var _apioptions = apiOptions(ajaxmethod, url, _payload);
				return requestAPI(_apioptions.url, urlHeaders)[ajaxmethod](_apioptions.param, progressReport).then(_success, _failure);
			}

			var _ajaxoptions$payload = ajaxoptions.payload,
			    payload = _ajaxoptions$payload === undefined ? {} : _ajaxoptions$payload,
			    headers = ajaxoptions.headers,
			    parameters = ajaxoptions.parameters,
			    success = ajaxoptions.success,
			    failure = ajaxoptions.failure,
			    progressReport = ajaxoptions.progressReport;

			urlHeaders = urlHeaders ? _Object$assign(urlHeaders, headers) : headers; // Override headers

			var apioptions = apiOptions(ajaxmethod, url, payload, parameters);
			return requestAPI(apioptions.url, urlHeaders)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
		};
	};

	//auto api functions creation...
	var userAPIS = {};
	for (var prop in apiJson) {

		var api = prop;
		var apivalue = apiJson[prop];

		var apiurl = apivalue.url;
		var apimethod = apivalue.method;

		//var apiFragments = api.split('/');
		var apiFragments = api.split('.');
		var lastObj = userAPIS;

		for (var j = 0; j < apiFragments.length; j++) {
			var apiFragment = apiFragments[j];
			if (apiFragment.indexOf(':') != -1) {
				continue; //Skipping this !api
			}

			if (apiFragment && typeof lastObj[apiFragment] === 'undefined') {
				lastObj[apiFragment] = httpConnection(apimethod).bind(null, apiurl);
			}

			if (apiFragment && typeof lastObj[apiFragment] !== 'undefined') {
				lastObj = lastObj[apiFragment];
			}
		}
	}

	return userAPIS;
};

var _class = function () {
	function _class(prefixUrl, defaultParams, authHeaders) {
		_classCallCheck(this, _class);

		this.prefixUrl = prefixUrl;
		this.defaultParams = defaultParams;
		this.authHeaders = authHeaders;
	}

	_createClass(_class, [{
		key: "create",
		value: function create(javaApiList, name) {

			var defaultParams = this.defaultParams ? this.defaultParams.bind(null, name) : null;
			var prefixUrl = this.prefixUrl ? this.prefixUrl.bind(null, name) : '';
			var authHeaders = this.authHeaders ? this.authHeaders.bind(null, name) : null;

			return Builder(javaApiList || {}, { defaultParams: defaultParams, prefixUrl: prefixUrl, authHeaders: authHeaders });
		}
	}]);

	return _class;
}();

export default _class;

==> js-api-creator-1.0.10.tgz: package/es/apiCreator.js <==
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _Object$keys from "babel-runtime/core-js/object/keys";
import _Object$assign from "babel-runtime/core-js/object/assign";
var _arguments = arguments;
import requestAPI from './xhrApi';

var isFormData = function isFormData(payload) {

	if (typeof FormData !== "undefined" && payload) {
		return payload.constructor == new FormData().constructor;
	}

	return typeof payload == "function";
};

var Builder = function Builder(apiJson, options) {
	//Url and param builder..
	var apiOptions = function apiOptions() {
		var _method = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

		var requestUrl = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
		var parameters = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
		var queryParameters = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};


		var userParams = parameters;
		var isFormDataParams = isFormData(parameters);
		if (!isFormDataParams) {
			userParams = _Object$assign({}, parameters); // to address re-back call ajax parameters keeping..
			if (_Object$keys(parameters).length) {
				var propsToUrl = requestUrl.split('/'); // helps to some parameter to url...
				for (var i = 0, len = propsToUrl.length; i < len; i++) {
					var prop = propsToUrl[i];
					var paramKey = prop.replace(':', '');
					if (prop.charAt(0) === ':' && userParams.hasOwnProperty(paramKey)) {
						var value = userParams[paramKey];
						requestUrl = requestUrl.replace('/' + prop, value ? '/' + value : '');
						requestUrl = requestUrl.replace(prop + '/', value ? value + '/' : '');
						delete userParams[paramKey];
					}
				}
			}
		}

		var defaultParams = _Object$assign({}, queryParameters, options.defaultParams(_method));
		var gobalParamsToUrl = '';
		var count = 0;
		for (var prop in defaultParams) {
			if (count > 0) {
				gobalParamsToUrl += "&" + prop + "=" + defaultParams[prop];
				break;
			}
			gobalParamsToUrl += prop + "=" + defaultParams[prop];
			count = 1;
		}

		gobalParamsToUrl = gobalParamsToUrl ? '?' + gobalParamsToUrl : '';

		if (!isFormDataParams) {
			var length = userParams ? _Object$keys(userParams).length : 0;
			userParams = length > 0 ? userParams : null;
		}

		return {
			url: options.prefixUrl(_method) + requestUrl + gobalParamsToUrl,
			param: userParams
		};
	};

	//url - bind arguments not from user..
	var httpConnection = function httpConnection(ajaxmethod) {
		return function (ajaxurl) {
			var ajaxoptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
			var ajaxoption2 = arguments[2];
			var ajaxoption3 = arguments[3];


			var urlHeaders = typeof options.authHeaders === "function" ? options.authHeaders(ajaxmethod) : null;
			var customOptions = options.customOptions || {};
			if (typeof ajaxoptions === "function" || typeof ajaxoption2 === "function") {

				var _success = typeof ajaxoptions === "function" ? ajaxoptions : ajaxoption2;
				var _failure = typeof ajaxoptions === "function" ? ajaxoption2 : ajaxoption3;
				var _payload = typeof ajaxoptions === "function" ? null : ajaxoptions;

				var _successCallback = function _successCallback() {
					customOptions.showLoader && customOptions.showLoader(ajaxmethod);
					_success && _success.apply(undefined, _arguments);
				};
				var _failureCallback = function _failureCallback() {
					customOptions.hideLoader && customOptions.hideLoader(ajaxmethod);
					_failure && _failure.apply(undefined, _arguments);
				};

				var _apiOptionsValue = apiOptions(ajaxmethod, ajaxurl, _payload || {});
				return requestAPI(_apiOptionsValue.url, urlHeaders)[ajaxmethod](_apiOptionsValue.param, progressReport).then(_successCallback, _failureCallback);
			}

			var url = ajaxoptions.url,
			    payload = ajaxoptions.payload,
			    headers = ajaxoptions.headers,
			    parameters = ajaxoptions.parameters,
			    success = ajaxoptions.success,
			    failure = ajaxoptions.failure,
			    progressReport = ajaxoptions.progressReport;

			urlHeaders = urlHeaders ? _Object$assign(urlHeaders, headers) : headers; // Override headers
			ajaxurl = ajaxurl || url;

			var successCallback = function successCallback() {
				customOptions.showLoader && customOptions.showLoader(ajaxmethod);
				success && success.apply(undefined, _arguments);
			};
			var failureCallback = function failureCallback() {
				customOptions.hideLoader && customOptions.hideLoader(ajaxmethod);
				failure && failure.apply(undefined, _arguments);
			};

			var apiOptionsValue = apiOptions(ajaxmethod, ajaxurl, payload || {}, parameters);
			return requestAPI(apiOptionsValue.url, urlHeaders)[ajaxmethod](apiOptionsValue.param, progressReport).then(successCallback, failureCallback);
		};
	};

	//auto api functions creation...
	var userAPIS = {};
	for (var prop in apiJson) {

		var api = prop;
		var apivalue = apiJson[prop];

		var apiurl = apivalue.url;
		var apimethod = apivalue.method;

		//var apiFragments = api.split('/');
		var apiFragments = api.split('.');
		var lastObj = userAPIS;

		for (var j = 0; j < apiFragments.length; j++) {
			var apiFragment = apiFragments[j];
			if (apiFragment.indexOf(':') != -1) {
				continue; //Skipping this !api
			}

			if (apiFragment && typeof lastObj[apiFragment] === 'undefined') {
				lastObj[apiFragment] = httpConnection(apimethod).bind(null, apiurl);
			}

			if (apiFragment && typeof lastObj[apiFragment] !== 'undefined') {
				lastObj = lastObj[apiFragment];
			}
		}
	}

	return userAPIS;
};

var _class = function () {
	function _class(prefixUrl, defaultParams, authHeaders, options) {
		_classCallCheck(this, _class);

		this.prefixUrl = prefixUrl;
		this.defaultParams = defaultParams;
		this.authHeaders = authHeaders;
		this.options = options;
	}

	_createClass(_class, [{
		key: "create",
		value: function create(javaApiList, name) {

			var defaultParams = this.defaultParams ? this.defaultParams.bind(null, name) : null;
			var prefixUrl = this.prefixUrl ? this.prefixUrl.bind(null, name) : '';
			var authHeaders = this.authHeaders ? this.authHeaders.bind(null, name) : null;
			var customOptions = this.options ? this.options : null;

			return Builder(javaApiList || {}, { defaultParams: defaultParams, prefixUrl: prefixUrl, authHeaders: authHeaders, customOptions: customOptions });
		}
	}]);

	return _class;
}();

export default _class;
